@@ -11,7 +11,6 @@ main(int argc,char *argv[])
     char prvfile[128]; int i;
     unsigned char k[16]; unsigned char iv[8];
     unsigned char hash[16];
-    unsigned char sig[MAXC];
     unsigned char *ss;
     FILE *private;
     init(e); init(p); init(q); init(c);
@@ -38,7 +37,7 @@ main(int argc,char *argv[])
 
     if (!read_numberx(private,p,k,iv) || !read_numberx(private,q,k,iv)) {
         fprintf(stderr, "wrong key to key entered or key corrupt\n");
-		zap(k,16); zap(hash,16); zap(sig,MAXC); zap(ss,strlen(ss));
+		zap(k,16); zap(hash,16);  zap(ss,strlen(ss));
         exit(1);
     }
 
@@ -47,6 +46,6 @@ main(int argc,char *argv[])
     mdfile(stdin, hash);    
     sign(c,hash,p,q,e);
     write_number(stdout,c);
-	zap(k,16); zap(hash,16); zap(sig,MAXC); zap(ss,strlen(ss));
+	zap(k,16); zap(hash,16);  zap(ss,strlen(ss));
     exit(0);
 }
