@@ -30,8 +30,14 @@ main(int argc,char *argv[])
         exit(1);
     }
     
-    read_number(public,n);
-    read_number(public,e);
+    if (!read_number(public,n)) {
+		fprintf(stderr, "fatal error reading %s (001)\n",pubfile);
+		exit(1);
+	}
+    if (!read_number(public,e)) {
+		fprintf(stderr, "fatal error reading %s (002)\n",pubfile);
+		exit(1);
+	}
 	if (!read_string(public,idstring)) {
 		fprintf(stderr, "warning: public key in %s is not self signed\n",pubfile);
 	}
